cache

package
v0.0.0-...-6c8a6c4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 15, 2022 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrKeyNotFound = errors.New("key is not found")

ErrKeyNotFound will return if selected key has been not found into inmemory storage.

Functions

func Del

func Del(key string)

Del removes selected key from inmemory storage.

func Get

func Get(key string) (value []byte, err error)

Get returns value by selected key from inmemory storage.

func Set

func Set(key string, value []byte) (err error)

Set override value by selected key into inmemory storage. If selected key is not definition in storage he will created.

Types

This section is empty.

Jump to