Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
Config is a structure for serialisation of a yaml file with definition of configurations all data sources.
type Source ¶
type Source struct {
Rule string `yaml:"rule"`
// If you create a new provider you should describe his mapping here.
StaticSrc provider.Static `yaml:"static"`
HttpSrc provider.Http `yaml:"http"`
FileSrc provider.File `yaml:"file"`
}
Source define available fields for description a source.
type StorageCronID ¶
StorageCronID is a structure of storage for all cron job ID of ran jobs.
Click to show internal directories.
Click to hide internal directories.